@@ -84,9 +84,12 @@ public:
      * It can be used for matching, but it cannot be used for parsing.
      * */
     static KDevelop::ParsingEnvironment* createStandardEnvironment();
+
+    static const KDevelop::ParsingEnvironment* standardEnvironment();
 private:
     void headerSectionEndedInternal(rpp::Stream* stream);
     bool checkAbort();
+    bool readContents();
 
     CppPreprocessEnvironment* m_currentEnvironment;
     KSharedPtr<Cpp::EnvironmentFile> m_firstEnvironmentFile; //First environment-file. If simplified matching is used, this is the proxy.
@@ -97,9 +100,12 @@ private:
     bool m_success;
     bool m_headerSectionEnded;
     rpp::pp* m_pp;
+    QByteArray m_contents;
+
+    static KDevelop::ParsingEnvironment* m_standardEnvironment;
 };
 
-KDevelop::ParsingEnvironment* createStandardEnvironment();
+KDevelop::ParsingEnvironment* CreateStandardEnvironment();
 
 #endif
 
