@@ -48,6 +48,7 @@ static QString currentBuildDirKey = "CurrentBuildDir";
 static QString currentCMakeBinaryKey = "Current CMake Binary";
 static QString currentBuildTypeKey = "CurrentBuildType";
 static QString currentInstallDirKey = "CurrentInstallDir";
+static QString currentExtraArgumentsKey = "Extra Arguments";
 static QString projectRootRelativeKey = "ProjectRootRelative";
 static QString projectBuildDirs = "BuildDirs";
 
@@ -91,6 +92,7 @@ bool checkForNeedingConfigure( KDevelop::ProjectBaseItem* item )
         cmakeGrp.writeEntry( currentBuildDirKey, bd.buildFolder() );
         cmakeGrp.writeEntry( currentCMakeBinaryKey, bd.cmakeBinary() );
         cmakeGrp.writeEntry( currentInstallDirKey, bd.installPrefix() );
+        cmakeGrp.writeEntry( currentExtraArgumentsKey, bd.extraArguments() );
         cmakeGrp.writeEntry( currentBuildTypeKey, bd.buildType() );
 
         if(!builddirs.contains(bd.buildFolder().toLocalFile())) {
@@ -146,6 +148,12 @@ QString projectRootRelative( KDevelop::IProject* project )
     return cmakeGrp.readEntry( projectRootRelativeKey, QString());
 }
 
+QString currentExtraArguments( KDevelop::IProject* project )
+{
+    KConfigGroup cmakeGrp = project->projectConfiguration()->group("CMake");
+    return cmakeGrp.readEntry( currentExtraArgumentsKey, "");
+}
+
 void setCurrentInstallDir( KDevelop::IProject* project, const KUrl& url )
 {
     KConfigGroup cmakeGrp = project->projectConfiguration()->group("CMake");
@@ -181,19 +189,24 @@ void setProjectRootRelative( KDevelop::IProject* project, const QString& relativ
     cmakeGrp.sync();
 }
 
+void setCurrentExtraArguments( KDevelop::IProject* project, const QString& string)
+{
+    KConfigGroup cmakeGrp = project->projectConfiguration()->group("CMake");
+    cmakeGrp.writeEntry( currentExtraArgumentsKey, string );
+    cmakeGrp.sync();
+}
+
 ICMakeDocumentation* cmakeDocumentation()
 {
-    KDevelop::IPlugin* p=KDevelop::ICore::self()->pluginController()->pluginForExtension(ICMakeDocumentation_iid);
+    ICMakeDocumentation* p=KDevelop::ICore::self()->pluginController()->extensionForPlugin<ICMakeDocumentation>("org.kdevelop.ICMakeDocumentation");
     
     if( !p ) 
     {
         return 0;
     }
 
-    ICMakeDocumentation* cmakedoc = qobject_cast<ICMakeDocumentation*>(p);
-    
-    Q_ASSERT(cmakedoc);
-    return cmakedoc;
+    Q_ASSERT(p);
+    return p;
 }
 
 QStringList allBuildDirs(KDevelop::IProject* project)
